@@ -11,7 +11,8 @@ geolitecity_url = 'http://geolite.maxmind.com/download/geoip/database/GeoLiteCit
 geolitecity_update = 2592000
 squid_cleanse_interval = 15
 squid_inactive_time = 180
-amqp_server_url = 'amqp://guest:guest@localhost:5672/%2F'
+amqp_server_url = 'amqp://guest:guest@localhost:5672'
+amqp_virtual_host = '/'
 amqp_server_queue = 'squiddata'
 amqp_exchange = 'shoal'
 amqp_exchange_type = 'topic'
@@ -29,6 +30,7 @@ def setup(path=None):
     global squid_cleanse_interval
     global squid_inactive_time
     global amqp_server_url
+    global amqp_virtual_host
     global amqp_server_queue
     global amqp_exchange
     global amqp_exchange_type
@@ -112,6 +114,10 @@ def setup(path=None):
         amqp_server_url = config_file.get("rabbitmq",
                                                 "amqp_server_url")
 
+    if config_file.has_option("rabbitmq", "amqp_virtual_host"):
+        amqp_virtual_host = config_file.get("rabbitmq",
+                                                "amqp_virtual_host")
+
     if config_file.has_option("rabbitmq", "amqp_server_queue"):
         amqp_server_queue = config_file.get("rabbitmq",
                                                 "amqp_server_queue")
